
<a id='changelog-2023.6.9'></a>
## [2023.6.9] - 2023-06-09

### Added

- Added RefundRequestAdmin

### Changed

- Updated README with new better instructions on setup and testing locally

<a id='changelog-2023.5.23'></a>
## [2023.5.23] - 2023-05-23

### Changed

- Updated README with new better instructions on setup and testing locally
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project uses date-based versioning.

## [0.8.0] - 2023-01-17

## [0.7.0] - 2022-11-14

## [0.6.0] - 2022-09-20

## [0.5.2] - 2022-08-26

## [0.5.1] - 2022-08-19

## [0.5.0] - 2022-08-04

## [0.4.0] - 2022-07-28

## [0.3.3] - 2022-07-27

## [0.3.2] - 2022-07-27

## [0.3.1] - 2022-07-26

## [0.3.0] - 2022-07-26

## [0.2.0] - 2022-07-19

## [0.1.0] - 2022-07-19

### Fixed
- Fixed an error that happens when handling row results

### Added

- Added `mitol.google_sheets_refunds` Google Sheets Refunds library.
- Added additional logging on exceptions